CLI
---

See :ref:`this <general/cli:command-line>` for command-line interface overview.

Exceptions reporter
^^^^^^^^^^^^^^^^^^^

.. automodule:: gordo.cli.exceptions_reporter
    :members:
    :undoc-members:
    :show-inheritance:

Click types
^^^^^^^^^^^

.. automodule:: gordo.cli.custom_types
    :members:
    :undoc-members:
    :show-inheritance:

Utils
^^^^^

.. automodule:: gordo.cli.cli
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: gordo.cli.workflow_generator
    :members:
    :undoc-members:
    :show-inheritance: